@@ -1,10 +1,8 @@
 from __future__ import division
 
 import unittest
-import warnings
 
 import av
-from av import time_base as AV_TIME_BASE
 
 from .common import TestCase, fate_suite
 
@@ -25,20 +23,18 @@ def step_forward(container, stream):
 
 
 class TestSeek(TestCase):
-
     def test_seek_float(self):
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
         self.assertRaises(TypeError, container.seek, 1.0)
-        self.assertRaises(TypeError, container.streams.video[0].seek, 1.0)
 
     def test_seek_int64(self):
         # Assert that it accepts large values.
         # Issue 251 pointed this out.
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
         container.seek(2**32)
 
     def test_seek_start(self):
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
 
         # count all the packets
         total_packet_count = 0
@@ -56,7 +52,7 @@ class TestSeek(TestCase):
         self.assertEqual(total_packet_count, seek_packet_count)
 
     def test_seek_middle(self):
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
 
         # count all the packets
         total_packet_count = 0
@@ -73,7 +69,7 @@ class TestSeek(TestCase):
         self.assertTrue(seek_packet_count < total_packet_count)
 
     def test_seek_end(self):
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
 
         # seek to middle
         container.seek(container.duration // 2)
@@ -95,9 +91,9 @@ class TestSeek(TestCase):
 
     def test_decode_half(self):
 
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
 
-        video_stream = next(s for s in container.streams if s.type == 'video')
+        video_stream = next(s for s in container.streams if s.type == "video")
         total_frame_count = 0
 
         # Count number of frames in video
@@ -109,7 +105,7 @@ class TestSeek(TestCase):
 
         # set target frame to middle frame
         target_frame = int(total_frame_count / 2.0)
-        target_timestamp = int((target_frame * AV_TIME_BASE) / video_stream.rate)
+        target_timestamp = int((target_frame * av.time_base) / video_stream.rate)
 
         # should seek to nearest keyframe before target_timestamp
         container.seek(target_timestamp)
@@ -130,11 +126,11 @@ class TestSeek(TestCase):
 
         self.assertEqual(frame_count, total_frame_count - target_frame)
 
-    def test_stream_seek(self, use_deprecated_api=False):
+    def test_stream_seek(self):
 
-        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
+        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
 
-        video_stream = next(s for s in container.streams if s.type == 'video')
+        video_stream = next(s for s in container.streams if s.type == "video")
         total_frame_count = 0
 
         # Count number of frames in video
@@ -149,14 +145,7 @@ class TestSeek(TestCase):
         target_sec = target_frame * 1 / rate
 
         target_timestamp = int(target_sec / time_base) + video_stream.start_time
-
-        if use_deprecated_api:
-            with warnings.catch_warnings(record=True) as captured:
-                video_stream.seek(target_timestamp)
-            self.assertEqual(len(captured), 1)
-            self.assertIn('Stream.seek is deprecated.', captured[0].message.args[0])
-        else:
-            container.seek(target_timestamp, stream=video_stream)
+        container.seek(target_timestamp, stream=video_stream)
 
         current_frame = None
         frame_count = 0
@@ -175,9 +164,6 @@ class TestSeek(TestCase):
 
         self.assertEqual(frame_count, total_frame_count - target_frame)
 
-    def test_deprecated_stream_seek(self):
-        self.test_stream_seek(use_deprecated_api=True)
-
 
 if __name__ == "__main__":
     unittest.main()
